What are you doing with goodplay?
=================================

.. note::

   This is reserved for your real-world examples.
   Please feel free to add your *project name* and *project link* to the list.

- None yet. Why not be the first?
